==> opennms-dao-api-17.0.0-20151014.002436-217-sources.jar: org/opennms/netmgt/dao/api/IsIsLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.IsIsLink;
import org.opennms.netmgt.model.OnmsNode;


public interface IsIsLinkDao extends OnmsDao<IsIsLink, Integer> {

    IsIsLink get(OnmsNode node, Integer isisCircIndex, Integer isisISAdjIndex);

    IsIsLink get(Integer nodeId, Integer isisCircIndex, Integer isisISAdjIndex);
    
    List<IsIsLink> findByNodeId(Integer nodeId);

    void deleteByNodeIdOlderThen(Integer nodeiId, Date now);

    List<Object[]> getLinksForTopology();
}

==> opennms-dao-api-18.0.0-20151030.215237-37-sources.jar: org/opennms/netmgt/dao/api/IsIsLinkDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.api;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.model.IsIsLink;
import org.opennms.netmgt.model.OnmsNode;
import org.opennms.netmgt.model.topology.IsisTopologyLink;


public interface IsIsLinkDao extends OnmsDao<IsIsLink, Integer> {

    IsIsLink get(OnmsNode node, Integer isisCircIndex, Integer isisISAdjIndex);

    IsIsLink get(Integer nodeId, Integer isisCircIndex, Integer isisISAdjIndex);
    
    List<IsIsLink> findByNodeId(Integer nodeId);

    void deleteByNodeIdOlderThen(Integer nodeiId, Date now);

    List<IsisTopologyLink> getLinksForTopology();
}
